@@ -43,10 +43,7 @@ RichTextEditorWidget::RichTextEditorWidget(QWidget *parent)
     init();
 }
 
-RichTextEditorWidget::~RichTextEditorWidget()
-{
-    delete d;
-}
+RichTextEditorWidget::~RichTextEditorWidget() = default;
 
 void RichTextEditorWidget::clear()
 {
@@ -101,7 +98,7 @@ QString RichTextEditorWidget::toPlainText() const
 void RichTextEditorWidget::init(RichTextEditor *customEditor)
 {
     auto lay = new QVBoxLayout(this);
-    lay->setContentsMargins(0, 0, 0, 0);
+    lay->setContentsMargins({});
     d->mTextToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
     lay->addWidget(d->mTextToSpeechWidget);
     if (customEditor) {
